import React, { useState, useEffect, useRef } from 'react';
import './index.less';
import { Input, Button, Upload, Form, Select, message, Modal } from 'antd';
const { Option } = Select;
import { PlusOutlined } from '@ant-design/icons';
import { Link, useIntl, connect, Dispatch, history } from 'umi';
import { event } from '@/.umi/plugin-locale/locale';

function getBase64(file) {
  return new Promise((resolve, reject) => {
    const reader = new FileReader();
    reader.readAsDataURL(file);
    reader.onload = () => resolve(reader.result);
    reader.onerror = (error) => reject(error);
  });
}
const Facilitys = (props: any) => {
  //传递值
  const { updata, disabled } = props;

  console.log(disabled);

  //上传列表
  const [fileList, setFileList] = useState([]);
  //显示隐藏
  const [previewVisible, setpreviewVisible] = useState(false);
  // 名称
  const [previewTitle, setpreviewTitle] = useState('');
  // 图片地址
  const [previewImage, setpreviewImage] = useState(null);

  // 新增按钮
  const uploadButton = (
    <div>
      <PlusOutlined />
      <div className="ant-upload-text">Upload</div>
    </div>
  );

  // 上传属性
  const uploadProps = {
    listType: 'picture-card',
    accept: '.jpeg,.png,.jpg',
    action: '/tos/image/upload',
    // fileList: fileList,
    onChange(info: any) {
      console.log(info);
      if (info.file.status === 'done') {
        message.success(`${info.file.name} file uploaded successfully`);
        // 拿到key 值  开始存储
        let list = fileList;
        // setFileList(list);      // 注意 不能直接赋值  因为使用完全绑定需要全部更新
        setFileList([...list]);
        console.log(fileList);
      } else if (info.file.status === 'error') {
        message.error(`${info.file.name} file upload failed.`);
      }
    },
  };

  // 上传
  const carryData = (key: any) => {
    console.log(`key值是${key}`);
    updata.identification = key;
    console.log(updata);
    return updata;
  };

  // 预览
  const handlePreview = async (file) => {
    if (!file.url && !file.preview) {
      file.preview = await getBase64(file.originFileObj);
    }
    setpreviewImage(file.url || file.preview);
    setpreviewTitle(file.name);
    setpreviewVisible(true);
  };

  // 点击遮罩回调
  const handleCancel = () => {
    setpreviewVisible(false);
  };

  // 点击移除图片
  const handRemove = () => {
    setFileList([...fileList]);
  };

  return (
    <>
      <Form.List
        name="names"
        rules={[
          {
            validator: async (_, names) => {
              // if (!names || names.length < 2) {
              //   return Promise.reject(new Error('At least 2 passengers'));
              // }
            },
          },
        ]}
      >
        {(fields, { add, remove }, { errors }) => (
          <>
            {fields.map((field, index) => (
              <Form.Item required={false} key={field.key} style={{ marginBottom: 0 }}>
                {/* 每一个上传的组件 */}
                <div className={'test'}>
                  <div className={'diybox'}>
                    <Upload
                      fileList={fileList}
                      data={carryData(index)}
                      {...uploadProps}
                      disabled={disabled}
                      onPreview={handlePreview}
                      onRemove={handRemove}
                    >
                      {/* 这里存在一个bug  当 key 超过 fileList 的默认值后 会报错 */}
                      {fileList.length >= 1 ? null : uploadButton}
                    </Upload>

                    <div className={'Facility'}>
                      <Form.Item
                        label={`Facility Name ${index}`}
                        name={field.key}
                        rules={[{ required: true, message: 'Please input Facility Name!' }]}
                      >
                        <Input placeholder="Facility Name" disabled={disabled} />
                      </Form.Item>
                      <div className={'over'}>
                        {fields.length > 1 ? (
                          <Button
                            type="link"
                            disabled={disabled}
                            onClick={() => remove(field.name)}
                          >
                            Delete
                          </Button>
                        ) : null}
                      </div>
                    </div>
                  </div>
                </div>
              </Form.Item>
            ))}
            {fields.length < 5 ? (
              <Form.Item>
                <Button
                  type="dashed"
                  onClick={() => add()}
                  style={{ width: '100px', height: '100px' }}
                  icon={<PlusOutlined />}
                  disabled={disabled}
                ></Button>
                <Form.ErrorList errors={errors} />
              </Form.Item>
            ) : null}
          </>
        )}
      </Form.List>

      {/* 预览表格 */}
      <Modal visible={previewVisible} title={previewTitle} footer={null} onCancel={handleCancel}>
        <img alt="example" style={{ width: '100%' }} src={previewImage} />
      </Modal>
    </>
  );
};

export default Facilitys;
