import React, { useState, useEffect, useRef } from 'react';

import styles from './index.less';

import { useIntl, connect, history } from 'umi';

import { Button, Tag, Table, Space, message } from 'antd';
import { timestampToTime } from '../../utils/time';

import { filterObj, urlEncode, filterObjbyTg } from '@/utils/method';

import TitleSearch from '../../components/TitleSearch/TitleSearch';

import ProTable, { ProColumns, TableDropdown, ActionType } from '@ant-design/pro-table';
interface readyData {
  [key: string]: any;
}

let readyData = {
  tosOwnerName: '',
  communityName: '',
  pageNum: 1,
};

const ChargeManager = (props: any) => {
  const { dispatch, location, Data } = props;

  const { formatMessage } = useIntl();
  const username = formatMessage({ id: 'R.charge.username' });
  const project = formatMessage({ id: 'R.charge.project' });
  const unit = formatMessage({ id: 'R.charge.unit' });
  const submissionTime = formatMessage({ id: 'R.charge.submissionTime' });
  const actions = formatMessage({ id: 'R.charge.actions' });

  const [loading, setLoading] = useState(false);

  const goToDetail = (values: any) => {
    getById(values);
    history.push('/PropertyManagementDetail');
  };

  const getById = (values: any) => {
    dispatch({ type: 'PropertyManagement/getById', playload: values });
  };

  const get = (values: any) => {
    dispatch({ type: 'PropertyManagement/get', playload: values });
  };
  // 进入页面先请求一次
  useEffect(() => {
    setLoading(true);
    get({
      communityName: '',
      tosOwnerName: '',
      pageNum: 1,
    });
  }, [1]);

  // 监听数据返回
  useEffect(() => {
    if (Data != null) {
      setLoading(false);
    }
  }, [Data]);

  // 搜索按钮
  const TitleSearchContent = (comment: any) => {
    setLoading(true);
    get({
      communityName: comment.communityName,
      tosOwnerName: comment.tosOwnerName,
      pageNum: 1,
    });
  };

  interface GithubIssueItem {
    url: string;
    id: number;
    number: number;
    title: string;
    labels: {
      name: string;
      color: string;
    }[];
    state: string;
    comments: number;
    created_at: string;
    updated_at: string;
    closed_at?: string;
  }

  const columns: ProColumns<GithubIssueItem>[] = [
    {
      title: 'User Name',
      dataIndex: 'tosOwnerName',
    },
    {
      title: 'Community Name',
      dataIndex: 'communityName',
    },
    {
      title: 'Unit',
      dataIndex: 'buildingNumber',
      render: (text: any, record: any) => (
        <div>{`${record.buildingNumber}#${record.floorNumber}-${record.roomNumber}`}</div>
      ),
    },
    {
      title: 'Submission Time',
      dataIndex: 'createTime',
      valueType: 'date',
      render: (text: any, record: any) => <div>{timestampToTime(record.createTime.time)}</div>,
    },
    {
      title: 'Actions',
      dataIndex: 'action',
      valueType: 'option',
      render: (text, record) => [<a onClick={goToDetail.bind(this, record)}>Detail</a>],
    },
  ];

  // 重置表单触发
  const resetHandler = () => {
    setLoading(true);
    readyData = {
      communityName: '',
      pageNum: 1,
      tosOwnerName: '',
    };
    get({
      ...readyData,
    });
  };

  // 切换页码
  const changePage = (value: any) => {
    readyData.pageNum = value.current;
    setLoading(true);
    get({
      ...readyData,
    });
  };

  return (
    <div className={styles.base}>
      <TitleSearch
        listkey={['tosOwnerName']}
        list={['TosOwnerName']}
        communitySelect={true}
        onSubmit={TitleSearchContent}
        // defaultValue={{ ...readyData }}
      />

      <ProTable<GithubIssueItem>
        columns={columns}
        dataSource={Data !== null ? Data.list : []}
        rowKey={'id'}
        search={false}
        loading={loading}
        onChange={changePage}
        pagination={{
          pageSize: Data !== null ? Data.page.curPageSize : 0,
          showSizeChanger: false,
          total: Data !== null ? Data.page.totalRow : '',
          current: Data !== null ? Data.page.currentPage : 1,
        }}
        options={{
          density: true,
          fullScreen: true,
          reload: () => {
            resetHandler();
          },
          setting: false,
        }}
      />
    </div>
  );
};

function mapStateToProps(state: any) {
  const { Data } = state.PropertyManagement;
  return {
    Data,
  };
}
export default connect(mapStateToProps)(ChargeManager);
